@@ -854,7 +854,7 @@ public:
   /**
    * This method is used to get a SQL reader for subsequent database access
    */
-  virtual KSharedPtr <MyMoneyStorageSql> connectToDatabase
+  virtual TDESharedPtr <MyMoneyStorageSql> connectToDatabase
       (const KURL& url);
   /**
     * This method is used when a database file is open, and the data is to
@@ -966,7 +966,7 @@ private:
   /**
     * This contains the interface with SQL reader for database access
     */
-  KSharedPtr <MyMoneyStorageSql> m_sql;
+  TDESharedPtr <MyMoneyStorageSql> m_sql;
 
   /**
     * This member variable keeps the User information.
